#[no_mangle]
pub unsafe extern "C" fn nstd_collections_vec_get(
    vec: &NSTDVec,
    pos: usize
) -> NSTDAny
Gets a pointer to an element from a vector. NOTE: The returned element pointer can quickly become a dangling pointer if the vector’s memory. gets reallocated or deallocated, so it is advised to create a copy of the element after getting it. Parameters: const NSTDVec *const vec - The vector. const NSTDUSize pos - The position of the element to get. Returns: NSTDAny element - Pointer to the element.