Module nstd::env

source · []
This is supported on crate feature nstd_env only.
Environment specific functionality and identification.

Functions

Returns a string describing the specific cpu architecture in use.

Returns a vector of strings that contain the cmd args that the program was started with.

Frees memory allocated by nstd_env_args.

Frees memory allocated by nstd_env_vars.

Gets an environment variable.

Returns a string describing the specific operating system in use.

Removes an environment variable. This will not free memory allocated by nstd_env_get_var.

Sets the current working directory.

Sets an environment variable.

Returns the path of a temporary directory.

Returns an array of strings that contain the environment variables.