Function nstd::collections::vec::nstd_collections_vec_pop
source · [−]Expand description
Pops a value off of the back of a vector and returns a pointer to it.
NOTE: This function follows the same behaviour rules as nstd_collections_vec_get.
Parameters:
NSTDVec *const vec - The vector.
Returns: NSTDAny element - The element that was removed.