Functions
Terminates the program in an abnormal fashion.
Exits the program with the specified exit code.
Parameters:
const NSTDExitCode code - The exit code.
Frees memory allocated by nstd_proc_spawn.
Parameters:
NSTDChildProcess *const handle - Pointer to a process handle.
Gets the current process’ ID.
Returns: NSTDProcessID id - The process ID.
Kills a process by it’s handle.
Does not free memory allocated by nstd_proc_spawn.
Parameters:
const NSTDChildProcess handle - The handle to the process.
Returns: NSTDErrorCode errc - Nonzero on error.
Gets the ID of a process by handle.
Parameters:
const NSTDChildProcess handle - The handle to the process.
Returns: NSTDProcessID id - The process ID.
Starts a new process.
Parameters:
const NSTDStr *const name - The name of the process.
const NSTDSlice *const args - Slice of NSTDStr arguments to pass to the process.
Returns: NSTDChildProcess handle - The handle to the new process, null on error.
Waits for a process to finish.
Does not free memory allocated by nstd_proc_spawn.
Parameters:
const NSTDChildProcess handle - The handle to the process.
NSTDExitCode **const code - The exit code from the process, null if none specified.
Type Definitions
Represents a process handle returned by nstd_proc_spawn.
An error code to be returned by a process.
Represents a process ID.