Structs
Represents a dynamic-sized array of UTF-8 chars.
Functions
Creates an NSTDSlice from an NSTDString.
Parameters:
const NSTDString *const string - The string.
Returns: NSTDSlice slice - The new slice.
Creates a string view from an NSTDString.
Parameters:
const NSTDString *const string - The string.
Returns: NSTDStr str - The new string view.
Returns the number of bytes used by this string.
Parameters:
const NSTDString *const string - The string.
Returns: NSTDUSize len - The number of bytes in the string.
Extends an NSTDString by an NSTDSlice of NSTDUnichars.
Parameters:
NSTDString *const string - The string.
const NSTDSlice chars - NSTDSlice of NSTDUnichars.
Frees an NSTDString instance.
Parameters:
NSTDString *const string - Pointer to a string.
Returns: NSTDErrorCode errc - Nonzero on error.
Creates a new NSTDString from a raw C string.
Parameters:
const NSTDChar *const cstr - The C string.
Returns: NSTDString string - The new NSTD string.
Creates an NSTDString from existing data.
Parameters:
const NSTDVec *const bytes - The existing raw data.
Returns: NSTDString string - The new NSTDString object.
Gets the length of a string.
Parameters:
const NSTDString *const string - The string.
Returns: NSTDUSize len - The length of the UTF-8 encoded string, -1 on error.
Creates a new NSTDString instance.
Returns: NSTDString string - The new string.
Removes an NSTDUnichar from the end of an NSTDString.
Parameters:
NSTDString *const string - The string.
Returns: NSTDUnichar chr - The unichar that was popped off the string, fill char on error.
Pushes an NSTDUnichar to an NSTDString.
Parameters:
NSTDString *const string - The string.
const NSTDUnichar chr - The unicode character to push to the string.
Returns: NSTDErrorCode errc - Nonzero on error.