This is supported on crate feature
nstd_time only.Expand description
Library for getting system times.
Structs
Represents a datetime object.
Functions
Gets an NSTDDateTime object representing the local time it was created.
Gets the time in seconds since the unix epoch.
Gets an NSTDDateTime object representing the UTC time it was created.